searchData={"content_type":"text/plain","items":[{"doc":"This module contains functions for signing requests to AWS services.","ref":"aws_signature.html","title":"aws_signature","type":"module"},{"doc":"Same as sign_v4/10 with no options.","ref":"aws_signature.html#sign_v4/9","title":"aws_signature.sign_v4/9","type":"function"},{"doc":"Implements the Signature Version 4 (SigV4) algorithm. This function takes AWS client credentials and request details, based on which it computes the signature and returns headers extended with the authorization entries. DateTime is a datetime tuple used as the request date. You most likely want to set it to the value of calendar:universal_time/0 when making the request. URL must be valid, with all components properly escaped. For example, &quot;https://example.com/path%20to&quot; is valid, whereas &quot;https://example.com/path to&quot; is not. It is essential that the provided request details are final and the returned headers are used to make the request. All custom headers need to be assembled before the signature is calculated. The signature is computed by normalizing request details into a well defined format and combining it with the credentials using a number of cryptographic functions. Upon receiving a request, the server calculates the signature using the same algorithm and compares it with the value received in headers. For more details check out the AWS documentation . The following options are supported: uri_encode_path When true , the request URI path is URI-encoded during request canonicalization, which is required for every service except S3 . Note that the given URL should already be properly encoded, so this results in each segment being URI-encoded twice, as expected by AWS. Defaults to true . body_digest Optional SHA256 digest of the request body. This option can be used to provide a fixed digest value, such as &quot;UNSIGNED-PAYLOAD&quot;, when sending requests without signing the body.","ref":"aws_signature.html#sign_v4/10","title":"aws_signature.sign_v4/10","type":"function"},{"doc":"Signs an AWS Event Stream message and returns the headers and signature used for next event signing. Headers of a sigv4 signed event message only contains 2 headers :chunk-signature computed signature of the event, binary string, bytes type :date millisecond since epoch, timestamp type PriorSignature for the first message is the base16 encoded signv4 of the request used to open a connection with the target service. HeadersString are the headers of the inner packet, encoded using the EventStream format.","ref":"aws_signature.html#sign_v4_event/7","title":"aws_signature.sign_v4_event/7","type":"function"},{"doc":"Same as sign_v4_query_params/7 with no options.","ref":"aws_signature.html#sign_v4_query_params/7","title":"aws_signature.sign_v4_query_params/7","type":"function"},{"doc":"Implements the Signature Version 4 (SigV4) algorithm for query parameters. This function takes AWS client credentials and request details, based on which it computes the signature and returns the URL extended with the signature entries. Note that anchors are ignored in the resulting URL. DateTime is a datetime tuple used as the request date. You most likely want to set it to the value of calendar:universal_time/0 when making the request. URL must be valid, with all components properly escaped. For example, &quot;https://example.com/path%20to&quot; is valid, whereas &quot;https://example.com/path to&quot; is not. It is essential that the provided request details are final and the returned query params are used to make the request with the provided URL. The signature is computed by normalizing request details into a well defined format and combining it with the credentials using a number of cryptographic functions. Upon receiving a request, the server calculates the signature using the same algorithm and compares it with the value received in headers. For more details check out the AWS documentation . The following options are supported: ttl Time-to-live value that tells how long this URL is valid in seconds. Defaults to 86400 , which means one day. uri_encode_path When true , the request URI path is URI-encoded during request canonicalization, which is required for every service except S3 . Note that the given URL should already be properly encoded, so this results in each segment being URI-encoded twice, as expected by AWS. Defaults to true . session_token Optional credential parameter if using credentials sourced from the STS service. body Request body to compute SHA256 digest for. Defaults to an empty binary. Note that body_digest always takes precedence when set. body_digest Optional SHA256 digest of the request body. This option can be used to provide a fixed digest value, such as &quot;UNSIGNED-PAYLOAD&quot;, when sending requests without signing the body, which is expected for S3 .","ref":"aws_signature.html#sign_v4_query_params/8","title":"aws_signature.sign_v4_query_params/8","type":"function"},{"doc":null,"ref":"aws_signature.html#t:header/0","title":"aws_signature.header/0","type":"type"},{"doc":null,"ref":"aws_signature.html#t:headers/0","title":"aws_signature.headers/0","type":"type"},{"doc":null,"ref":"aws_signature.html#t:query_param/0","title":"aws_signature.query_param/0","type":"type"},{"doc":null,"ref":"aws_signature.html#t:query_params/0","title":"aws_signature.query_params/0","type":"type"},{"doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).\n\n## [v0.3.2](https://github.com/aws-beam/aws_signature/tree/v0.3.2) (2024-02-16)\n\n#","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"- Add support for signing AWS event stream messages ([#23](https://github.com/aws-beam/aws_signature/pull/23))\n- Add body_digest option to sign_v4/10 ([#25](https://github.com/aws-beam/aws_signature/pull/25))\n\n## [v0.3.1](https://github.com/aws-beam/aws_signature/tree/v0.3.1) (2022-04-27)\n\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Signature for URLs with explicit port component ([#18](https://github.com/aws-beam/aws_signature/pull/18))\n\n## [v0.3.0](https://github.com/aws-beam/aws_signature/tree/v0.3.0) (2022-04-12)\n\nThis release changes the default behaviour of `sign_v4_query_params`. Instead of\nsetting the body digest to \"UNSIGNED-PAYLOAD\" it now computes the digest of an\nempty string. To retain the current behaviour you need to pass an option:\n\n```diff\n-sign_v4_query_params(AccessKeyID, SecretAccessKey, Region, Service, DateTime, Method, URL, []).\n+sign_v4_query_params(AccessKeyID, SecretAccessKey, Region, Service, DateTime, Method, URL, [{body_digest,  >}]).\n```\n\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Support for body signing in presigned requests ([#15](https://github.com/aws-beam/aws_signature/pull/15))\n\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Default body digest in `sign_v4_query_params` signature ([#15](https://github.com/aws-beam/aws_signature/pull/15))\n\n## [v0.2.0](https://github.com/aws-beam/aws_signature/tree/v0.2.0) (2021-09-27)\n\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Changed `sign_v4_query_params` signatures to also accept HTTP method ([#11](https://github.com/aws-beam/aws_signature/pull/11))\n\n## [v0.1.1](https://github.com/aws-beam/aws_signature/tree/v0.1.1) (2021-08-28)\n\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Support for query string signature ([#7](https://github.com/aws-beam/aws_signature/pull/7))\n\n## [v0.1.0](https://github.com/aws-beam/aws_signature/tree/v0.1.0) (2021-08-17)\n\nInitial release","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   Copyright 2021, Jonatan Kłosko  .\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html","title":"LICENSE","type":"extras"}]}